<?php
require_once 'config.php';

// ---------- 1. Enable Error Reporting ----------
error_reporting(E_ALL);
ini_set('display_errors', 1);

echo "🟢 Process initiated...<br>";
logMessage("🟢 Process initiated...");

// ---------- 2. Check cURL Installation ----------
if (!function_exists('curl_version')) {
    logMessage("❌ cURL is not enabled on this server.");
    die("❌ cURL is not enabled on this server.");
} else {
    logMessage("✅ cURL is enabled.");
    echo "✅ cURL is enabled.<br>";
}

// ---------- 3. Refresh Access Token ----------
function refreshToken() {
    echo "🔄 Attempting to refresh access token...<br>";
    logMessage("🔄 Attempting to refresh access token...");

    $ch = curl_init();

    curl_setopt($ch, CURLOPT_URL, 'https://www.ssgenius.com/mautic-data-fetcher/token_handler.php');
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_TIMEOUT, 30);

    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    $error = curl_error($ch);
    curl_close($ch);

    echo "🌐 HTTP Response Code: $httpCode<br>";
    echo "📄 Response: $response<br>";
    echo "⚠️ CURL Error: $error<br>";

    logMessage("🌐 HTTP Response Code: $httpCode");
    logMessage("📄 Response: $response");
    logMessage("⚠️ CURL Error: $error");

    if ($httpCode === 200 && strpos($response, 'Authorization successful') !== false) {
        logMessage("🔑 Access token refreshed successfully.");
        echo "✅ Token refreshed successfully.<br>";

        // Fetch the latest token after refresh
        $conn = new mysqli(DB_HOST, DB_USER, DB_PASSWORD, DB_NAME);
        $result = $conn->query("SELECT access_token FROM emma_mason_api_tokens WHERE client_name='emma_mason' LIMIT 1");

        if ($result && $result->num_rows > 0) {
            $GLOBALS['accessToken'] = $result->fetch_assoc()['access_token'];
            logMessage("🔓 Access token loaded for fetching campaigns.");
        } else {
            logMessage("❌ Access token not found after refresh.");
            die("Access token not found. Exiting...");
        }

        $conn->close();
    } else {
        logMessage("❌ Error refreshing access token. HTTP Code: $httpCode. Response: $response. Error: $error");
        die("Token refresh failed. Exiting...");
    }
}

// ---------- 4. Include Campaign Fetch Function ----------
require_once __DIR__ . '/includes/fetch_campaigns.php';

// ---------- 5. Include Email Fetch Function ----------
require_once __DIR__ . '/includes/fetch_emails.php';

// ---------- 6. Include Segment Fetch Function ----------
require_once __DIR__ . '/includes/fetch_segments.php';

// ---------- 7. Run Token Refresh ----------
refreshToken();

echo "🚀 Fetching campaigns...<br>";
fetchAndSaveCampaigns();
echo "✅ Finished fetching campaigns.<br>";
logMessage("✅ Finished fetching campaigns.");

echo "📨 Fetching emails...<br>";
fetchAndSaveEmails();
echo "✅ Finished fetching emails.<br>";
logMessage("✅ Finished fetching emails.");

echo "📊 Fetching segments...<br>";
fetchAndSaveSegments(); // Corrected function name
echo "✅ Finished fetching segments.<br>";
logMessage("✅ Finished fetching segments.");


// ---------- 8. Fetch and Save Tags ----------
require_once __DIR__ . '/includes/fetch_tags.php';  // Include the tags fetch script

echo "🏷️ Fetching tags...<br>";
fetchAndSaveTags();  // Call the function to fetch and save tags
echo "✅ Finished fetching tags.<br>";
logMessage("✅ Finished fetching tags.");

