<?php
// Include configuration and utility functions
require_once __DIR__ . '/../config.php';
require_once __DIR__ . '/../includes/utils.php';

// *****************************************
// * Bounce Events Fetch & Save (Webhook) *
// *****************************************

function fetchAndSaveBouncesByWebhook() {
    global $accessToken;
    echo "🟢 Process initiated...<br>";
    echo "✅ cURL is enabled.<br>";
    echo "🚀 Fetching bounce events...<br>";

    // Fetch all contacts from Mautic (customize this function)
    $contactIds = getAllContactIds(); 

    foreach ($contactIds as $contactId) {
        $url = MAUTIC_BASE_URL . "/api/contacts/$contactId/activity";
        logMessage("📦 Fetching activity for Contact ID: $contactId from URL: $url");
        echo "📦 Fetching activity for Contact ID: $contactId from URL: $url<br>";

        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, ["Authorization: Bearer $accessToken", "Content-Type: application/json"]);
        $response = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if ($httpCode === 200) {
            $data = json_decode($response, true);
            $events = $data['events'] ?? [];

            foreach ($events as $event) {
                if ($event['event'] === "lead.donotcontact" && $event['details']['dnc']['reason'] === "Communication bounced for this channel.") {
                    saveBounceEventByWebhook($contactId, $event);
                }
            }
        } else {
            logMessage("❌ Failed to fetch activity for Contact ID: $contactId. HTTP Code: $httpCode");
            echo "❌ Failed to fetch activity for Contact ID: $contactId. HTTP Code: $httpCode<br>";
        }
    }
}

function saveBounceEventByWebhook($contactId, $event) {
    $conn = dbConnect();
    $stmt = $conn->prepare("
        INSERT INTO mautic_bounce_by_webhook_events (
            lead_id, bounce_id, bounce_date, bounce_details, other_bounce_info, email_id, campaign_id
        ) VALUES (?, ?, ?, ?, ?, ?, ?)
    ");

    $bounceId = $event['details']['dnc']['id'];
    $bounceDate = convertToMySQLDateTime($event['timestamp']);
    $bounceDetails = $event['details']['dnc']['comments'];
    $otherInfo = $event['details']['dnc']['reason'];
    $emailId = findClosestEmailEvent($event['timestamp'], $contactId);
    $campaignId = findCampaignId($emailId);

    $stmt->bind_param(
        "iisssii",
        $contactId,
        $bounceId,
        $bounceDate,
        $bounceDetails,
        $otherInfo,
        $emailId,
        $campaignId
    );

    if ($stmt->execute()) {
        logMessage("✅ Bounce saved for Contact ID: $contactId - Bounce ID: $bounceId");
        echo "✅ Bounce saved for Contact ID: $contactId - Bounce ID: $bounceId<br>";
    } else {
        logMessage("❌ Failed to save Bounce for Contact ID: $contactId - Error: " . $stmt->error);
    }

    $stmt->close();
    $conn->close();
}

function findClosestEmailEvent($timestamp, $leadId) {
    // Logic to find the closest email event (sent) before the bounce
    // For now, return placeholder data
    return 161; // Placeholder email ID
}

function findCampaignId($emailId) {
    // Logic to fetch the campaign ID associated with the email
    // For now, return placeholder data
    return 17; // Placeholder campaign ID
}

function getAllContactIds() {
    // Fetch all contact IDs from Mautic
    // For now, return a placeholder list
    return [264419]; // Example contact ID
}

// Start the process
fetchAndSaveBouncesByWebhook();
