<?php
// Include configuration and utility functions
require_once __DIR__ . '/../config.php';
require_once __DIR__ . '/../includes/utils.php';

// *****************************************
// * Segment Fetch, Save & Leads Fetch     *
// *****************************************

function fetchAndSaveSegments() {
    global $accessToken;
    echo "🟢 Process initiated...<br>";
    echo "✅ cURL is enabled.<br>";
    echo "🚀 Fetching segments...<br>";

    $url = MAUTIC_BASE_URL . "/api/segments";
    logMessage("📦 Fetching segments from URL: $url");
    echo "📦 Fetching segments from URL: $url<br>";

    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, ["Authorization: Bearer $accessToken", "Content-Type: application/json"]);
    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($httpCode === 200) {
        $data = json_decode($response, true);
        $segments = $data['lists'] ?? [];
        $fetchedCount = count($segments);

        if ($fetchedCount > 0) {
            saveSegmentInventory($segments);
            foreach ($segments as $segment) {
                fetchAndSaveSegmentLeads($segment['id']);
            }
        } else {
            logMessage("🛑 No segments to fetch.");
            echo "🛑 No segments to fetch.<br>";
        }
    } else {
        logMessage("❌ Failed to fetch segments. HTTP Code: $httpCode");
        echo "❌ Failed to fetch segments. HTTP Code: $httpCode<br>";
    }
}

function saveSegmentInventory($segments) {
    $conn = dbConnect();
    $stmt = $conn->prepare("
        REPLACE INTO emma_mason_segment_list (
            segment_id, name, alias, description, is_published, filters, created_at, updated_at, date_added, date_modified
        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
    ");

    foreach ($segments as $segment) {
        $segmentId = (int)$segment['id'];
        $name = is_string($segment['name']) ? $segment['name'] : json_encode($segment['name']);
        $alias = is_string($segment['alias']) ? $segment['alias'] : json_encode($segment['alias']);
        $description = is_string($segment['description']) ? $segment['description'] : json_encode($segment['description']);
        $isPublished = isset($segment['isPublished']) && $segment['isPublished'] ? 1 : 0;
        $filters = isset($segment['filters']) ? json_encode($segment['filters']) : null;
        $createdAt = isset($segment['created_at']) ? convertToMySQLDateTime($segment['created_at']) : null;
        $updatedAt = isset($segment['updated_at']) ? convertToMySQLDateTime($segment['updated_at']) : null;
        $dateAdded = isset($segment['dateAdded']) ? convertToMySQLDateTime($segment['dateAdded']) : null;
        $dateModified = isset($segment['dateModified']) ? convertToMySQLDateTime($segment['dateModified']) : null;

        // Bind variables (by reference) to the prepared statement
        $stmt->bind_param(
            "isssssssss",
            $segmentId,
            $name,
            $alias,
            $description,
            $isPublished,
            $filters,
            $createdAt,
            $updatedAt,
            $dateAdded,
            $dateModified
        );

        if ($stmt->execute()) {
            logMessage("✅ Saved Segment ID: $segmentId - $name");
            echo "✅ Saved Segment ID: $segmentId - $name<br>";
        } else {
            logMessage("❌ Failed to save Segment ID: $segmentId - Error: " . $stmt->error);
        }
    }

    $stmt->close();
    $conn->close();
}

function fetchAndSaveSegmentLeads($segmentId) {
    global $accessToken;

    $limit = 100; // Number of leads per API call
    $start = 0; // Pagination offset

    echo "📥 Fetching leads for Segment ID: $segmentId<br>";

    while (true) {
        $url = MAUTIC_BASE_URL . "/api/contacts?segment=$segmentId&limit=$limit&start=$start";
        logMessage("📥 Fetching leads for Segment ID: $segmentId from URL: $url");
        echo "📥 Fetching leads for Segment ID: $segmentId from URL: $url<br>";

        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, ["Authorization: Bearer $accessToken", "Content-Type: application/json"]);
        $response = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if ($httpCode === 200) {
            $data = json_decode($response, true);
            $leads = $data['contacts'] ?? [];

            if (!empty($leads)) {
                saveSegmentLeads($segmentId, $leads);
                $start += $limit; // Move to the next page
            } else {
                logMessage("🛑 No more leads found for Segment ID: $segmentId.");
                echo "🛑 No more leads found for Segment ID: $segmentId.<br>";
                break; // Exit the loop if no more leads
            }
        } else {
            logMessage("❌ Failed to fetch leads for Segment ID: $segmentId. HTTP Code: $httpCode");
            echo "❌ Failed to fetch leads for Segment ID: $segmentId. HTTP Code: $httpCode<br>";
            break; // Exit on error
        }
    }
}


function saveSegmentLeads($segmentId, $leads) {
    $conn = dbConnect();

    foreach ($leads as $lead) {
        $leadId = $lead['id'];
        $dateIncluded = convertToMySQLDateTime($lead['dateAdded']); // Convert ISO 8601 to MySQL DATETIME

        // Check if the lead is already in the segment
        $result = $conn->query("SELECT 1 FROM leads_segments WHERE segment_id = $segmentId AND lead_id = $leadId");
        
        if ($result->num_rows > 0) {
            // If exists, update the date_included
            $conn->query("UPDATE leads_segments SET date_included = '$dateIncluded' WHERE segment_id = $segmentId AND lead_id = $leadId");
        } else {
            // If not, insert a new record
            $conn->query("INSERT INTO leads_segments (segment_id, lead_id, date_included) VALUES ($segmentId, $leadId, '$dateIncluded')");
        }
    }

    $conn->close();
}



// Call the fetch and save function
fetchAndSaveSegments();
