<?php
require_once __DIR__ . '/../config.php';
require_once __DIR__ . '/utils.php';

// Connect to the database
$conn = new mysqli(DB_HOST, DB_USER, DB_PASSWORD, DB_NAME);

if ($conn->connect_error) {
    logMessage("❌ [DB] Connection failed: " . $conn->connect_error);
    die("Connection failed: " . $conn->connect_error);
}

// Truncate the table before any other operation
$truncateSQL = "TRUNCATE TABLE click_date_and_total_sales_report;";
if ($conn->query($truncateSQL) === TRUE) {
    logMessage("✅ [TABLE RESET] Table click_date_and_total_sales_report truncated successfully.");
} else {
    logMessage("❌ [TABLE RESET ERROR] Failed to truncate table click_date_and_total_sales_report. Error: " . $conn->error);
}

logMessage("🚀 [PROCESS] Starting full database extraction with lead details...");

// Initial parameters
$batchSize = 10000; // Number of distinct original_id per iteration
$startingOriginalId = 0; // Start from the first record
$processedRecords = []; // Array to track unique combinations

while (true) {
    logMessage("🔄 [BATCH] Processing batch with startingOriginalId: $startingOriginalId...");

    // Fetch the next batch of original_ids
    $sqlDistinctOriginalIds = "
        SELECT DISTINCT original_id
        FROM parsed_json_details
        WHERE original_id > $startingOriginalId
        ORDER BY original_id ASC
        LIMIT $batchSize;
    ";

    $distinctResult = $conn->query($sqlDistinctOriginalIds);

    if ($distinctResult->num_rows > 0) {
        $originalIds = [];
        while ($row = $distinctResult->fetch_assoc()) {
            $originalIds[] = $row['original_id'];
        }

        $originalIdList = implode(", ", $originalIds);
        logMessage("✅ [NEXT ORIGINAL IDS] Found Original IDs: $originalIdList");

        // Process each original_id
        foreach ($originalIds as $originalId) {
            // Fetch details for the original_id
            $sqlDetails = "
                SELECT 
                    pjd.original_id,
                    mph.date_hit AS click_date,
                    pjd.key_value AS email_id,
                    (SELECT key_value FROM parsed_json_details WHERE key_name = 'ct.stat' AND original_id = pjd.original_id) AS stat,
                    (SELECT key_value FROM parsed_json_details WHERE key_name = 'ct.lead' AND original_id = pjd.original_id) AS lead_id,
                    (SELECT key_value FROM parsed_json_details WHERE key_name = 'utm_campaign' AND original_id = pjd.original_id) AS utm_campaign,
                    (SELECT key_value FROM parsed_json_details WHERE key_name = 'utm_source' AND original_id = pjd.original_id) AS utm_source,
                    (SELECT key_value FROM parsed_json_details WHERE key_name = 'utm_content' AND original_id = pjd.original_id) AS utm_content
                FROM parsed_json_details pjd
                JOIN mautic_page_hits mph ON pjd.original_id = mph.id
                WHERE pjd.original_id = $originalId
                  AND pjd.key_name = 'ct.email'
                  AND pjd.key_value IS NOT NULL
                  AND pjd.key_value != ''
                  AND pjd.key_value != '0'
                LIMIT 1;
            ";

            $detailsResult = $conn->query($sqlDetails);

            if ($detailsResult->num_rows > 0) {
                $row = $detailsResult->fetch_assoc();

                // Skip if any critical field is empty, null, or zero
                if (
                    empty($row['click_date']) || 
                    empty($row['email_id']) || $row['email_id'] == 0 || 
                    empty($row['stat']) || $row['stat'] == 0
                ) {
                    logMessage("⚠️ [SKIP] Invalid data for Original ID: $originalId. Skipping...");
                    continue;
                }

                $combinationKey = $row['click_date'] . "|" . $row['email_id'] . "|" . $row['stat'];

                // Check for duplicates inside PHP array
                if (isset($processedRecords[$combinationKey])) {
                    logMessage("⚠️ [SKIP] Duplicate record found in PHP array: click_date={$row['click_date']}, email_id={$row['email_id']}, stat={$row['stat']}");
                    continue;
                }

                // Mark the combination as processed
                $processedRecords[$combinationKey] = true;

                $leadId = $row['lead_id'];
                $clickDate = $row['click_date'];

                // Fetch additional lead details from mautic_leads
                $leadDetailsSQL = "
                    SELECT 
                        latest_order_date,
                        latest_order_amount
                    FROM mautic_leads
                    WHERE id = $leadId
                      AND latest_order_amount > 0
                      AND latest_order_date >= '$clickDate'
                      AND latest_order_date <= DATE_ADD('$clickDate', INTERVAL 7 DAY);
                ";

                $leadDetailsResult = $conn->query($leadDetailsSQL);

                $totalSalesIn7Days = 0;
                $latestOrderDate = NULL;
                $latestOrderAmount = 0;

                if ($leadDetailsResult->num_rows > 0) {
                    $leadDetailsRow = $leadDetailsResult->fetch_assoc();
                    $latestOrderDate = $leadDetailsRow['latest_order_date'];
                    $latestOrderAmount = $leadDetailsRow['latest_order_amount'];
                    $totalSalesIn7Days = $latestOrderAmount; // Assign sales amount
                }

                // Insert data in the table
                $insertSQL = "
                    INSERT INTO click_date_and_total_sales_report (
                        click_date, email_id, stat, lead_id, campaign_name, utm_source, utm_content, 
                        total_sales_in_7_days, latest_order_date, latest_order_amount
                    ) VALUES (
                        '{$conn->real_escape_string($row['click_date'] ?? '')}',
                        {$conn->real_escape_string($row['email_id'] ?? '0')},
                        '{$conn->real_escape_string($row['stat'] ?? '')}',
                        {$conn->real_escape_string($leadId ?? '0')},
                        '{$conn->real_escape_string($row['utm_campaign'] ?? '')}',
                        '{$conn->real_escape_string($row['utm_source'] ?? '')}',
                        '{$conn->real_escape_string($row['utm_content'] ?? '')}',
                        {$conn->real_escape_string($totalSalesIn7Days ?? '0')},
                        " . ($latestOrderDate ? "'{$conn->real_escape_string($latestOrderDate)}'" : "NULL") . ",
                        {$conn->real_escape_string($latestOrderAmount ?? '0')}
                    );
                ";


                if ($conn->query($insertSQL) === TRUE) {
                    logMessage("✅ [INSERT] Record inserted successfully: click_date={$row['click_date']}, email_id={$row['email_id']}, stat={$row['stat']}");
                } else {
                    logMessage("❌ [INSERT ERROR] Failed to insert record: click_date={$row['click_date']}, email_id={$row['email_id']}, stat={$row['stat']}. Error: " . $conn->error);
                }
            } else {
                logMessage("⚠️ [DETAILS] No valid record found for Original ID: $originalId");
            }
        }

        // Update the startingOriginalId for the next batch
        $startingOriginalId = max($originalIds);
    } else {
        logMessage("🚫 [NEXT ORIGINAL IDS] No more Original IDs found to process.");
        break; // Termina el bucle si no hay más registros
    }
}

logMessage("🎉 [PROCESS] Full database extraction with lead details completed.");

// Additional process: Update latest_order_amount and latest_order_date from mautic_leads table
$updateSQL = "
    UPDATE click_date_and_total_sales_report cts
    JOIN mautic_leads ml
    ON cts.lead_id = ml.id
    SET 
        cts.latest_order_amount = ml.latest_order_amount,
        cts.latest_order_date = ml.latest_order_date
    WHERE ml.latest_order_amount IS NOT NULL
      AND ml.latest_order_date IS NOT NULL;
";

if ($conn->query($updateSQL) === TRUE) {
    logMessage("✅ [UPDATE] Successfully updated latest_order_amount and latest_order_date from mautic_leads.");
} else {
    logMessage("❌ [UPDATE ERROR] Failed to update latest_order_amount and latest_order_date: " . $conn->error);
}


$conn->close();
