<?php
require_once 'config.php';

function refreshAccessToken() {
    $url = MAUTIC_BASE_URL . "/oauth/v2/token";

    $postFields = [
        'client_id' => MAUTIC_CLIENT_ID,
        'client_secret' => MAUTIC_CLIENT_SECRET,
        'grant_type' => 'client_credentials'
    ];

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postFields));
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // Change to true for production
    $response = curl_exec($ch);

    if ($response === false) {
        $error = curl_error($ch);
        curl_close($ch);
        die("❌ cURL Error: $error");
    }

    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    $responseData = json_decode($response, true);

    echo "<pre>HTTP Code: $httpCode\n";
    echo "Response:\n";
    print_r($responseData);
    echo "</pre>";

    if ($httpCode === 200 && isset($responseData['access_token'])) {
        $accessToken = $responseData['access_token'];
        $expiresIn = $responseData['expires_in'];
        $refreshToken = $responseData['refresh_token'] ?? null;  // Handle missing refresh token

        $conn = new mysqli(DB_HOST, DB_USER, DB_PASSWORD, DB_NAME);
        if ($conn->connect_error) {
            die("❌ Database connection failed: " . $conn->connect_error);
        }

        $stmt = $conn->prepare("
            REPLACE INTO emma_mason_api_tokens 
            (client_name, access_token, refresh_token, expires_at) 
            VALUES ('emma_mason', ?, ?, DATE_ADD(NOW(), INTERVAL ? SECOND))
        ");

        if (!$stmt) {
            die("❌ SQL Prepare failed: " . $conn->error);
        }

        $stmt->bind_param("ssi", $accessToken, $refreshToken, $expiresIn);

        if (!$stmt->execute()) {
            die("❌ SQL Execution failed: " . $stmt->error);
        }

        $stmt->close();
        $conn->close();

        echo "✅ Authorization successful. Tokens have been stored.";
    } else {
        echo "❌ Authorization failed. HTTP Code: $httpCode. Response: ";
        print_r($responseData);
    }
}

refreshAccessToken();
?>
